@@ -1,4 +1,4 @@
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 ## Import packages
 import numpy as np
@@ -96,7 +96,7 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
     nchannels : int, optional
         Number of basis channels in basis set. Note that iterative shifting will be applied such that reconstructions will always be of stim_max length, regardless of number of channels specified. Defaults to 9.
     channel_sd : float, optional
-        The standard deviation of each channel of the basis set. Defaults to cosine raised to nchannels-1, or approximately 39° SD.
+        The standard deviation of each channel of the basis set. Defaults to standard deviation of a cosine raised to nchannels-1.
     channel_mus : array_like, optional
         The centers of each channel. Defaults to equally spaced channels. Due to iterative shifting, the centers of each channel are inconsequential if assuming equal spacing. However, if you do not want equally spaced channels (e.g., one channel is always farther apart from the other channels), then provide an array of the centers of each channel (in stimulus space). Note that iterative shifting is applied in all cases.
     plot_basis_set: bool, optional
